@@ -125,6 +125,29 @@ setGeneric (
 ##
 
 
+
+## compute product revenues
+setMethod(
+  f= "calcRevenues",
+  signature= "Cournot",
+  definition=function(object,preMerger=TRUE, market = FALSE){
+    
+    
+    if( preMerger) { quantities <- object@quantityPre}
+    else{quantities <- object@quantityPost}
+    
+    prices <- calcPrices(object, preMerger)
+    
+    res <- t(prices * t(quantities))
+    
+    if(market){return( sum(res) )}
+    else{return(res)}
+    
+    
+    
+  })
+
+
 setMethod(
   f= "calcShares",
   signature= "Cournot",
@@ -476,21 +499,10 @@ setMethod(
   definition=function(object,preMerger=TRUE){
     
     
-    if( preMerger) {
-      prices <- object@pricePre
-      quantities <- object@quantityPre
-      
-    }
-    else{prices <- object@pricePost
-    quantities <- object@quantityPost
-    
-    }
-    
-    
-    
+    rev <-  calcRevenues(object, preMerger= preMerger)
     vc <- calcVC(object, preMerger= preMerger)
     
-    ps <- colSums(prices*t(quantities), na.rm=TRUE) - vc
+    ps <- rowSums(rev, na.rm=TRUE) - vc
     names(ps) <- object@labels[[1]]
     
     return(ps)
@@ -510,18 +522,22 @@ setMethod(
 setMethod(
   f= "calcQuantities",
   signature= "Cournot",
-  definition=function(object,preMerger=TRUE,...){
+  definition=function(object,preMerger=TRUE,market=FALSE,...){
     
     slopes <- object@slopes
     intercepts <- object@intercepts
     quantityStart <- object@quantityStart
     #quantityStart[is.na(quantityStart)] = 0
     
-    if(preMerger){ owner  <- object@ownerPre
+    if(preMerger){ 
+    if(market) return(sum(object@quantityPre, na.rm=TRUE))  
+    owner  <- object@ownerPre
     products  <- object@productsPre
     cap <- object@capacitiesPre
     }
-    else{          owner <-  object@ownerPost
+    else{    
+      if(market) return(sum(object@quantityPost, na.rm=TRUE))  
+    owner <-  object@ownerPost
     products <-  object@productsPost
     cap <- object@capacitiesPost
     }
@@ -575,7 +591,7 @@ setMethod(
     
     
     ## Find price changes that set FOCs equal to 0
-    minResult <- BB::BBsolve( quantityStart,FOC, quiet=TRUE,control=object@control.equ,...)
+    minResult <- BB::BBsolve( quantityStart,FOC, quiet=TRUE,control=object@control.equ)
     
     if(minResult$convergence != 0){warning("'calcQuantities' nonlinear solver may not have successfully converged. 'BBsolve' reports: '",minResult$message,"'")}
     
@@ -642,7 +658,7 @@ setMethod(
 setMethod(
   f= "cmcr",
   signature= "Cournot",
-  definition=function(object){
+  definition=function(object,...){
     
     owner <- object@ownerPre
     isParty <- rowSums( abs(object@ownerPost - object@ownerPre) ) > 0
